@@ -1,5 +1,4 @@
 import type { Client } from "@open-rpc/client-js";
-import lodash from "lodash";
 
 export enum Strategy {
   default = "default",
@@ -132,8 +131,11 @@ export class Api {
     return await this._request({ method: "config/read", params: { profile: profile } });
   }
 
-  async writeProfile(config: Config): Promise<Config> {
-    return await this._request({ method: "config/write", params: { values: config } });
+  async writeProfile(config: Config, infer_game_flavour: boolean): Promise<Config> {
+    return await this._request({
+      method: "config/write",
+      params: { values: config, infer_game_flavour: infer_game_flavour },
+    });
   }
 
   async deleteProfile(profile: string): Promise<void> {
@@ -149,7 +151,7 @@ export class Api {
       method: "sources/list",
       params: { profile: this.profile },
     });
-    return lodash.fromPairs(result.map((i: Sources["foo"]) => [i.source, i]));
+    return Object.fromEntries(result.map((i: Sources["foo"]) => [i.source, i]));
   }
 
   async list(): Promise<ListResult> {
@@ -162,6 +164,7 @@ export class Api {
   async search(
     searchTerms: string,
     searchLimit: number,
+    sources: string[] | null,
     strategy: Strategy
   ): Promise<MultiResult> {
     return await this._request({
@@ -170,6 +173,7 @@ export class Api {
         profile: this.profile,
         search_terms: searchTerms,
         limit: searchLimit,
+        sources: sources,
         strategy: strategy,
       },
     });
