@@ -9,7 +9,6 @@ from textwrap import dedent, fill
 from typing import (
     TYPE_CHECKING,
     AbstractSet,
-    Any,
     Callable,
     FrozenSet,
     Generator,
@@ -22,7 +21,6 @@ from typing import (
     Type,
     TypeVar,
     Union,
-    cast,
     overload,
 )
 
@@ -34,7 +32,7 @@ from .resolvers import Defn, MultiPkgModel, Strategy
 from .utils import TocReader, cached_property, get_version, is_outdated, tabulate, uniq
 
 if TYPE_CHECKING:
-    from .manager import CliManager as CliManagerT
+    from .manager import CliManager
 
     _R = TypeVar('_R')
 
@@ -79,7 +77,7 @@ class Report:
         )
 
     def generate(self):
-        manager: CliManagerT = click.get_current_context().obj.m
+        manager: CliManager = click.get_current_context().obj.m
         if manager.config.auto_update_check:
             outdated, new_version = manager.run(is_outdated())
             if outdated:
@@ -110,7 +108,7 @@ class ManagerWrapper:
         self.ctx = ctx
 
     @cached_property
-    def m(self) -> CliManagerT:
+    def m(self) -> CliManager:
         from .manager import CliManager
 
         try:
@@ -132,7 +130,7 @@ class EnumParam(click.Choice, Generic[_EnumT]):
     def __init__(
         self,
         choice_enum: Type[_EnumT],
-        excludes: AbstractSet[_EnumT] = set(),
+        excludes: AbstractSet[_EnumT] = frozenset(),
         case_sensitive: bool = True,
     ) -> None:
         self.choice_enum = choice_enum
@@ -146,27 +144,12 @@ class EnumParam(click.Choice, Generic[_EnumT]):
         return self.choice_enum[parent_result]
 
 
-def _callbackify(fn: Callable[..., _R]) -> Callable[[click.Context, click.Parameter, Any], _R]:
+def _callbackify(fn: Callable[..., _R]) -> Callable[[click.Context, click.Parameter, object], _R]:
     return lambda c, _, v: fn(c.obj.m, v)
 
 
-def _show_version(ctx: click.Context, _param: click.Parameter, value: bool):
-    if value:
-        __version__ = get_version()
-        click.echo(f'instawow, version {__version__}')
-        ctx.exit()
-
-
 @click.group(context_settings={'help_option_names': ('-h', '--help')})
-@click.option(
-    '--version',
-    is_flag=True,
-    default=False,
-    expose_value=False,
-    is_eager=True,
-    callback=_show_version,
-    help='Show the version and exit.',
-)
+@click.version_option(get_version(), prog_name=__package__)
 @click.option(
     '--debug',
     'log_level',
@@ -175,27 +158,32 @@ def _show_version(ctx: click.Context, _param: click.Parameter, value: bool):
     callback=lambda _, __, v: 'DEBUG' if v else 'INFO',
     help='Log more things.',
 )
-@click.option('--profile', '-p', default='__default__', help='Activate the specified profile.')
+@click.option(
+    '--profile',
+    '-p',
+    default='__default__',
+    help='Activate the specified profile.',
+)
 @click.pass_context
-def main(ctx: click.Context, log_level: bool, profile: str):
+def main(ctx: click.Context, log_level: str, profile: str):
     "Add-on manager for World of Warcraft."
     ctx.obj = ManagerWrapper(ctx)
 
 
 @overload
-def parse_into_defn(manager: CliManagerT, value: str, *, raise_invalid: bool = True) -> Defn:
+def parse_into_defn(manager: CliManager, value: str, *, raise_invalid: bool = True) -> Defn:
     ...
 
 
 @overload
 def parse_into_defn(
-    manager: CliManagerT, value: List[str], *, raise_invalid: bool = True
+    manager: CliManager, value: List[str], *, raise_invalid: bool = True
 ) -> List[Defn]:
     ...
 
 
 def parse_into_defn(
-    manager: CliManagerT, value: Union[str, List[str]], *, raise_invalid: bool = True
+    manager: CliManager, value: Union[str, List[str]], *, raise_invalid: bool = True
 ) -> Union[Defn, List[Defn]]:
     if not isinstance(value, str):
         defns = (parse_into_defn(manager, v, raise_invalid=raise_invalid) for v in value)
@@ -211,31 +199,31 @@ def parse_into_defn(
 
 
 def parse_into_defn_with_strategy(
-    manager: CliManagerT, value: Sequence[Tuple[Strategy, str]]
-) -> List[Defn]:
+    manager: CliManager, value: Sequence[Tuple[Strategy, str]]
+) -> Iterable[Defn]:
     defns = parse_into_defn(manager, [d for _, d in value])
-    return list(map(Defn.with_strategy, defns, (s for s, _ in value)))
+    return map(Defn.with_strategy, defns, (s for s, _ in value))
 
 
 def parse_into_defn_with_version(
-    manager: CliManagerT, value: Sequence[Tuple[str, str]]
-) -> List[Defn]:
+    manager: CliManager, value: Sequence[Tuple[str, str]]
+) -> Iterable[Defn]:
     defns = parse_into_defn(manager, [d for _, d in value])
-    return list(map(Defn.with_version, defns, (v for v, _ in value)))
+    return map(Defn.with_version, defns, (v for v, _ in value))
 
 
-def parse_into_defn_from_json_file(manager: CliManagerT, path: Path) -> List[Defn]:
+def parse_into_defn_from_json_file(manager: CliManager, path: Path) -> Iterable[Defn]:
     faux_pkgs = MultiPkgModel.parse_file(path, encoding='utf-8')
-    return list(map(Defn.from_pkg, cast('List[models.Pkg]', faux_pkgs.__root__)))
+    return map(Defn.from_pkg, faux_pkgs.__root__)
 
 
 def combine_addons(
-    fn: Callable[[CliManagerT, Any], List[Defn]],
+    fn: Callable[[CliManager, object], List[Defn]],
     ctx: click.Context,
     click_param: click.Parameter,
-    value: Any,
+    value: object,
 ) -> None:
-    addons = ctx.params.setdefault('addons', [])
+    addons: List[Defn] = ctx.params.setdefault('addons', [])
     if value:
         addons.extend(fn(ctx.obj.m, value))
 
@@ -298,8 +286,12 @@ def update(obj: ManagerWrapper, addons: Sequence[Defn]) -> None:
 
     def filter_results(result: E.ManagerResult):
         # Hide packages from output if they are up to date
-        # and ``update`` was invoked without args
-        return cast(bool, addons) or not isinstance(result, E.PkgUpToDate)
+        # and ``update`` was invoked without args,
+        # provided that they are not pinned
+        if addons or not isinstance(result, E.PkgUpToDate):
+            return True
+        else:
+            return result.is_pinned
 
     results = obj.m.run(
         obj.m.update(
@@ -331,7 +323,7 @@ def rollback(ctx: click.Context, addon: Defn, undo: bool) -> None:
     "Roll an add-on back to an older version."
     from .prompts import Choice, select
 
-    manager: CliManagerT = ctx.obj.m
+    manager: CliManager = ctx.obj.m
     limit = 10
 
     pkg = manager.get_pkg(addon)
@@ -362,12 +354,13 @@ def rollback(ctx: click.Context, addon: Defn, undo: bool) -> None:
     reconstructed_defn = Defn.from_pkg(pkg)
     choices = [
         Choice(
-            [('', v.version)],  # type: ignore
+            [('', v.version)],
+            value=v.version,
             disabled='installed version' if v.version == pkg.version else None,
         )
         for v in versions
     ]
-    selection = select(
+    selection: str = select(
         f'Select version of {reconstructed_defn} for rollback', choices
     ).unsafe_ask()
     Report(
@@ -385,7 +378,13 @@ def rollback(ctx: click.Context, addon: Defn, undo: bool) -> None:
 @click.pass_context
 def reconcile(ctx: click.Context, auto: bool, list_unreconciled: bool) -> None:
     "Reconcile pre-installed add-ons."
-    from .matchers import AddonFolder, get_folder_set, match_dir_names, match_toc_ids, match_toc_names
+    from .matchers import (
+        AddonFolder,
+        get_folder_set,
+        match_dir_names,
+        match_toc_ids,
+        match_toc_names,
+    )
     from .models import is_pkg
     from .prompts import PkgChoice, confirm, select, skip
 
@@ -408,17 +407,16 @@ def reconcile(ctx: click.Context, auto: bool, list_unreconciled: bool) -> None:
         '''
     )
 
-    manager: CliManagerT = ctx.obj.m
+    manager: CliManager = ctx.obj.m
 
     def prompt_one(addons: List[AddonFolder], pkgs: List[models.Pkg]) -> Union[Defn, Tuple[()]]:
         def construct_choice(pkg: models.Pkg):
             defn = Defn.from_pkg(pkg)
             title = [
-                ('', str(defn)),
-                ('', '=='),
+                ('', f'=={defn}'),
                 ('class:highlight-sub' if highlight_version else '', pkg.version),
             ]
-            return PkgChoice(title, defn, pkg=pkg)
+            return PkgChoice(title, pkg=pkg, value=defn)
 
         # Highlight version if there's multiple of them
         highlight_version = len({i.version for i in chain(addons, pkgs)}) > 1
@@ -432,7 +430,7 @@ def reconcile(ctx: click.Context, auto: bool, list_unreconciled: bool) -> None:
         uniq_defns = uniq(d for _, b in groups for d in b)
         results = manager.run(manager.resolve(uniq_defns))
         for addons, defns in groups:
-            shortlist = list(filter(is_pkg, (results[d] for d in defns)))
+            shortlist: List[models.Pkg] = list(filter(is_pkg, (results[d] for d in defns)))
             if shortlist:
                 selection = Defn.from_pkg(shortlist[0]) if auto else prompt_one(addons, shortlist)
                 selection and (yield selection)
@@ -483,19 +481,27 @@ def reconcile(ctx: click.Context, auto: bool, list_unreconciled: bool) -> None:
     type=click.IntRange(1, 20, clamp=True),
     help='A number to limit results to.',
 )
+@click.option(
+    '--source',
+    'sources',
+    multiple=True,
+    help='A source to search in.  Repeatable.',
+)
 @click.pass_context
-def search(ctx: click.Context, search_terms: str, limit: int) -> None:
+def search(ctx: click.Context, search_terms: str, limit: int, sources: Sequence[str]) -> None:
     "Search for add-ons to install."
     from .prompts import PkgChoice, checkbox, confirm
 
-    manager: CliManagerT = ctx.obj.m
+    manager: CliManager = ctx.obj.m
 
-    pkgs = manager.run(manager.search(search_terms, limit))
+    pkgs = manager.run(manager.search(search_terms, limit, frozenset(sources) or None))
     if pkgs:
         choices = [PkgChoice(f'{p.name}  ({d}=={p.version})', d, pkg=p) for d, p in pkgs.items()]
         selections = checkbox('Select add-ons to install', choices=choices).unsafe_ask()
         if selections and confirm('Install selected add-ons?').unsafe_ask():
             ctx.invoke(install, addons=selections)
+    else:
+        click.echo('No results found.')
 
 
 class ListFormats(enum.Enum):
@@ -525,9 +531,12 @@ def list_installed(
     from sqlalchemy import and_, or_
 
     def format_deps(pkg: models.Pkg):
-        deps = (Defn(pkg.source, d.id) for d in pkg.deps)
-        deps = (d.with_(name=getattr(obj.m.get_pkg(d), 'slug', d.alias)) for d in deps)
-        return map(str, deps)
+        return (
+            str(d.with_(alias=p.slug) if p else d)
+            for d in pkg.deps
+            for d in (Defn(pkg.source, d.id),)
+            for d, p in ((d, obj.m.get_pkg(d)),)
+        )
 
     def get_wowi_desc_from_toc(pkg: models.Pkg):
         if pkg.source == 'wowi':
@@ -592,9 +601,7 @@ def reveal(obj: ManagerWrapper, addon: Defn) -> None:
     "Bring an add-on up in your file manager."
     pkg = obj.m.get_pkg(addon, partial_match=True)
     if pkg:
-        import webbrowser
-
-        webbrowser.open((obj.m.config.addon_dir / pkg.folders[0].name).as_uri())
+        click.launch(str(obj.m.config.addon_dir / pkg.folders[0].name), locate=True)
     else:
         Report([(addon, E.PkgNotInstalled())]).generate_and_exit()
 
@@ -620,9 +627,8 @@ def _show_active_config(ctx: click.Context, _param: click.Parameter, value: bool
 def configure(ctx: click.Context) -> Config:
     "Configure instawow."
     from prompt_toolkit.completion import PathCompleter, WordCompleter
-    from questionary import text
 
-    from .prompts import PydanticValidator
+    from .prompts import PydanticValidator, text
 
     addon_dir = text(
         'Add-on directory: ',
