@@ -17,6 +17,7 @@ from typing import (
     Iterator,
     List,
     Optional as O,
+    Set,
     Tuple,
     Type,
     TypeVar,
@@ -29,6 +30,7 @@ from aiohttp import web
 from aiohttp_rpc import JsonRpcMethod, WsJsonRpcServer, middlewares as rpc_middlewares
 from aiohttp_rpc.errors import InvalidParams as InvalidParamsError, ServerError
 from pydantic import BaseModel, ValidationError, validator
+from typing_extensions import Literal
 from yarl import URL
 
 from . import exceptions as E
@@ -37,7 +39,7 @@ from .manager import Manager, init_web_client
 from .matchers import get_folder_set, match_dir_names, match_toc_ids, match_toc_names
 from .models import Pkg, is_pkg
 from .resolvers import Defn, PkgModel, Strategy
-from .utils import Literal, get_version, is_outdated, run_in_thread as t, uniq
+from .utils import get_version, is_outdated, run_in_thread as t, uniq
 
 if TYPE_CHECKING:
     _T = TypeVar('_T')
@@ -78,12 +80,18 @@ class _DefnParamMixin(BaseModel):
 
 class WriteConfigParams(BaseParams):
     values: Dict[str, Any]
+    infer_game_flavour: bool
     _method = 'config/write'
 
     @t
     def respond(self, managers: ManagerWorkQueue) -> Config:
         with _reraise_validation_error(_ConfigError):
-            config = Config(**self.values).write()
+            config = Config(**self.values)
+            if self.infer_game_flavour:
+                config.game_flavour = (
+                    'classic' if Config.is_classic_folder(config.addon_dir) else 'retail'
+                )
+            config.write()
 
         # Dispose of the ``Manager`` corresponding to the profile so that it is
         # re-loaded on next invocation of ``ManagerWorkQueue.run``
@@ -174,7 +182,7 @@ class MultiResult(BaseModel):
     __root__: List[Union[SuccessResult, ErrorResult]]
 
     @validator('__root__', each_item=True, pre=True)
-    def _classify_tuple(cls, value: Tuple[str, Any]) -> Union[SuccessResult, ErrorResult]:
+    def _classify_tuple(cls, value: Tuple[str, object]) -> Union[SuccessResult, ErrorResult]:
         status, result = value
         if status == 'success':
             return SuccessResult(status=status, addon=result)
@@ -185,6 +193,7 @@ class MultiResult(BaseModel):
 class SearchParams(_ProfileParamMixin, BaseParams):
     search_terms: str
     limit: int
+    sources: O[Set[str]] = None
     strategy: Strategy = Strategy.default
     _method = 'search'
 
@@ -195,6 +204,7 @@ class SearchParams(_ProfileParamMixin, BaseParams):
                 Manager.search,
                 search_terms=self.search_terms,
                 limit=self.limit,
+                sources=self.sources,
                 strategy=self.strategy,
             ),
         )
@@ -222,7 +232,7 @@ class ResolveParams(_ProfileParamMixin, _DefnParamMixin, BaseParams):
             ),
         )
         return MultiResult.parse_obj(
-            [('success', r) if is_pkg(r) else (r.kind, r.message) for r in results.values()]
+            [('success', r) if is_pkg(r) else (r.status, r.message) for r in results.values()]
         )
 
 
@@ -236,7 +246,7 @@ class InstallParams(_ProfileParamMixin, _DefnParamMixin, BaseParams):
         )
         return MultiResult.parse_obj(
             [
-                (r.kind, r.pkg if isinstance(r, E.PkgInstalled) else r.message)
+                (r.status, r.pkg if isinstance(r, E.PkgInstalled) else r.message)
                 for r in results.values()
             ]
         )
@@ -251,7 +261,7 @@ class UpdateParams(_ProfileParamMixin, _DefnParamMixin, BaseParams):
         )
         return MultiResult.parse_obj(
             [
-                (r.kind, r.new_pkg if isinstance(r, E.PkgUpdated) else r.message)
+                (r.status, r.new_pkg if isinstance(r, E.PkgUpdated) else r.message)
                 for r in results.values()
             ]
         )
@@ -264,7 +274,7 @@ class RemoveParams(_ProfileParamMixin, _DefnParamMixin, BaseParams):
         results = await managers.run(self.profile, partial(Manager.remove, defns=self.defns))
         return MultiResult.parse_obj(
             [
-                (r.kind, r.old_pkg if isinstance(r, E.PkgRemoved) else r.message)
+                (r.status, r.old_pkg if isinstance(r, E.PkgRemoved) else r.message)
                 for r in results.values()
             ]
         )
@@ -277,7 +287,7 @@ class PinParams(_ProfileParamMixin, _DefnParamMixin, BaseParams):
         results = await managers.run(self.profile, partial(Manager.pin, defns=self.defns))
         return MultiResult.parse_obj(
             [
-                (r.kind, r.pkg if isinstance(r, E.PkgInstalled) else r.message)
+                (r.status, r.pkg if isinstance(r, E.PkgInstalled) else r.message)
                 for r in results.values()
             ]
         )
