@@ -12,6 +12,7 @@ from shutil import copy
 from tempfile import NamedTemporaryFile
 from typing import (
     TYPE_CHECKING,
+    AbstractSet,
     Any,
     AsyncIterator,
     Awaitable,
@@ -29,7 +30,6 @@ from typing import (
     Type,
     TypeVar,
     Union,
-    cast,
 )
 
 from loguru import logger
@@ -62,6 +62,7 @@ from .utils import (
     run_in_thread as t,
     shasum,
     trash,
+    uniq,
 )
 
 if TYPE_CHECKING:
@@ -158,7 +159,7 @@ async def cache_response(
         text = await t(dest.read_text)(encoding='utf-8')
     else:
         method = request_kwargs.pop('method', 'GET')
-        kwargs = {'raise_for_status': True, **request_kwargs}
+        kwargs: Dict[str, Any] = {'raise_for_status': True, **request_kwargs}
         if label:
             kwargs = {**kwargs, 'trace_request_ctx': {'report_progress': True, 'label': label}}
         async with manager.web_client.request(method, url, **kwargs) as response:
@@ -234,7 +235,7 @@ def init_web_client(**kwargs: Any) -> aiohttp.ClientSession:
         'connector': TCPConnector(force_close=True, limit_per_host=10),
         'headers': {'User-Agent': USER_AGENT},
         'trust_env': True,  # Respect the 'http_proxy' env var
-        'timeout': cast(Any, ClientTimeout)(connect=15),
+        'timeout': ClientTimeout(connect=10, sock_read=10),  # type: ignore
         **kwargs,
     }
     return ClientSession(**kwargs)
@@ -244,7 +245,7 @@ class _DummyLock:
     async def __aenter__(self) -> None:
         pass
 
-    async def __aexit__(self, *args: Any) -> None:
+    async def __aexit__(self, *args: object) -> None:
         pass
 
 
@@ -268,13 +269,14 @@ def _error_out(error: BaseException) -> Callable[[], Awaitable[NoReturn]]:
     return inner
 
 
-async def _capture_exc_async(
-    coro: Callable[..., Awaitable[_T]]
+async def capture_manager_exc_async(
+    awaitable: Awaitable[_T],
 ) -> Union[_T, E.ManagerError, E.InternalError]:
+    "Capture and log an exception raised in a coroutine."
     from aiohttp import ClientError
 
     try:
-        return await coro()
+        return await awaitable
     except (E.ManagerError, E.InternalError) as error:
         return error
     except ClientError as error:
@@ -290,7 +292,7 @@ def _with_lock(
     manager_bound: bool = True,
 ) -> Callable[[_T], _T]:
     def outer(coro_fn: _T):
-        async def inner(self: Manager, *args: Any, **kwargs: Any):
+        async def inner(self: Manager, *args: object, **kwargs: object):
             key = f'{id(self)}_{lock_name}' if manager_bound else lock_name
             async with self.locks[key]:
                 return await coro_fn(self, *args, **kwargs)
@@ -317,12 +319,12 @@ class Manager:
         self.config = config
         self.database = database
         self.resolvers = _ResolverDict((r.source, r(self)) for r in resolver_classes)
-        self._catalogue: O[Catalogue] = catalogue
+        self._catalogue = catalogue
 
     @classmethod
     def from_config(cls: Type[_ManagerT], config: Config) -> _ManagerT:
         session_factory = prepare_database(config)
-        return cls(config, cast('SqlaSession', session_factory()))
+        return cls(config, session_factory())
 
     @property
     def web_client(self) -> aiohttp.ClientSession:
@@ -350,7 +352,7 @@ class Manager:
         try:
             return _locks.get()
         except LookupError:
-            locks = cast('DefaultDict[str, asyncio.Lock]', defaultdict(_DummyLock))
+            locks: DefaultDict[str, Any] = defaultdict(_DummyLock)
             _locks.set(locks)
             logger.debug('using dummy lock factory')
             return locks
@@ -514,19 +516,18 @@ class Manager:
         complexity for something that I would never expect to
         encounter in the wild.
         """
-        pkgs = list(filter(is_pkg, results))
-        dep_defns = list(
+        pkgs = [r for r in results if is_pkg(r)]
+        dep_defns = uniq(
             filterfalse(
                 {(p.source, p.id) for p in pkgs}.__contains__,
-                # Using a dict to maintain dep appearance order
-                {(p.source, d.id): ... for p in pkgs for d in p.deps},
+                ((p.source, d.id) for p in pkgs for d in p.deps),
             )
         )
         if not dep_defns:
             return {}
 
         deps = await self.resolve(list(starmap(Defn, dep_defns)))
-        pretty_deps = {d.with_(name=r.slug) if is_pkg(r) else d: r for d, r in deps.items()}
+        pretty_deps = {d.with_(alias=r.slug) if is_pkg(r) else d: r for d, r in deps.items()}
         return pretty_deps
 
     async def resolve(self, defns: Sequence[Defn], with_deps: bool = False) -> Dict[Defn, Any]:
@@ -538,11 +539,8 @@ class Manager:
 
         defns_by_source = bucketise(defns, key=lambda v: v.source)
         results = await gather(
-            (
-                _capture_exc_async(partial(self.resolvers[s].resolve, b))
-                for s, b in defns_by_source.items()
-            ),
-            False,
+            (self.resolvers[s].resolve(b) for s, b in defns_by_source.items()),
+            capture_manager_exc_async,
         )
         results_by_defn = chain_dict(
             defns,
@@ -557,7 +555,11 @@ class Manager:
         return results_by_defn
 
     async def search(
-        self, search_terms: str, limit: int, strategy: Strategy = Strategy.default
+        self,
+        search_terms: str,
+        limit: int,
+        sources: O[AbstractSet[str]] = None,
+        strategy: Strategy = Strategy.default,
     ) -> Dict[Defn, Pkg]:
         "Search the master catalogue for packages by name."
         import heapq
@@ -569,25 +571,28 @@ class Manager:
         w = 0.5  # Weighing edit distance and download score equally
         normalise = normalise_names()
 
+        if sources is None:
+            sources = self.resolvers.keys()
+
         s = normalise(search_terms)
-        defns_by_token = bucketise(
+        tokens_to_entries = bucketise(
             (
                 (i.normalised_name, i)
                 for i in catalogue.__root__
-                if self.config.game_flavour in i.game_compatibility
+                if self.config.game_flavour in i.game_compatibility and i.source in sources
             ),
             key=lambda v: v[0],
         )
         matches = heapq.nlargest(
             limit,
-            ((jaro_winkler_similarity(s, n), n) for n in defns_by_token),
+            ((jaro_winkler_similarity(s, n), n) for n in tokens_to_entries),
             key=lambda v: v[0],
         )
         weighted_entries = sorted(
             (
                 (-(s * w + i.derived_download_score * (1 - w)), i)
                 for s, m in matches
-                for _, i in defns_by_token[m]
+                for _, i in tokens_to_entries[m]
             ),
             key=lambda v: v[0],
         )
@@ -610,11 +615,9 @@ class Manager:
             compress(resolve_results.items(), (not self.get_pkg(d) for d in resolve_results))
         )
         installables = {
-            (d, cast(Pkg, r)): download_archive(self, r)
-            for d, r in resolve_results.items()
-            if is_pkg(r)
+            (d, r): download_archive(self, r) for d, r in resolve_results.items() if is_pkg(r)
         }
-        archives = await gather(installables.values())
+        archives = await gather(installables.values(), capture_manager_exc_async)
         result_coros = chain_dict(
             defns,
             _error_out(E.PkgAlreadyInstalled()),
@@ -630,7 +633,7 @@ class Manager:
             ),
         )
         results: Dict[Defn, Any] = {
-            d: await _capture_exc_async(c) for d, c in result_coros.items()
+            d: await capture_manager_exc_async(c()) for d, c in result_coros.items()
         }
         return results
 
@@ -653,20 +656,21 @@ class Manager:
             for d, p in zip(defns, (self.get_pkg(d) for d in defns))
         }
         resolve_results = await self.resolve([d for d, p in defns_to_pkgs.items() if p])
-        installables = {d: cast(Pkg, r) for d, r in resolve_results.items() if is_pkg(r)}
+        installables = {d: r for d, r in resolve_results.items() if is_pkg(r)}
         updatables = {
             (d, o, n): download_archive(self, n)
-            for (d, n), o in zip(
-                installables.items(), (cast(Pkg, defns_to_pkgs[d]) for d in installables)
-            )
-            if n.version != o.version
+            for (d, n), o in zip(installables.items(), (defns_to_pkgs[d] for d in installables))
+            if n.version != o.version  # type: ignore
         }
-        archives = await gather(updatables.values())
+        archives = await gather(updatables.values(), capture_manager_exc_async)
         result_coros = chain_dict(
             defns_to_pkgs,
             _error_out(E.PkgNotInstalled()),
             ((d, _error_out(r)) for d, r in resolve_results.items()),
-            zip(installables, repeat(_error_out(E.PkgUpToDate()))),
+            (
+                (d, _error_out(E.PkgUpToDate(is_pinned=d.strategy is Strategy.version)))
+                for d in installables
+            ),
             (
                 (
                     d,
@@ -678,7 +682,7 @@ class Manager:
             ),
         )
         results: Dict[Defn, Any] = {
-            d: await _capture_exc_async(c) for d, c in result_coros.items()
+            d: await capture_manager_exc_async(c()) for d, c in result_coros.items()
         }
         return results
 
@@ -692,7 +696,7 @@ class Manager:
             ((d, partial(t(self.remove_pkg), p)) for d, p in zip(defns, maybe_pkgs) if p),
         )
         results: Dict[Defn, Any] = {
-            d: await _capture_exc_async(c) for d, c in result_coros.items()
+            d: await capture_manager_exc_async(c()) for d, c in result_coros.items()
         }
         return results
 
@@ -710,20 +714,17 @@ class Manager:
 
         strategies = {Strategy.default, Strategy.version}
 
-        def pin(defns: Sequence[Defn]) -> Iterable[E.ManagerResult]:
-            for defn in defns:
-                pkg = self.get_pkg(defn)
-                if pkg:
-                    if {defn.strategy} <= strategies <= self.resolvers[pkg.source].strategies:
-                        pkg.options.strategy = defn.strategy.name
-                        self.database.commit()
-                        yield E.PkgInstalled(pkg)
-                    else:
-                        yield E.PkgStrategyUnsupported(defn.strategy)
-                else:
-                    yield E.PkgNotInstalled()
+        def pin(defn: Defn, pkg: O[Pkg]) -> E.ManagerResult:
+            if not pkg:
+                return E.PkgNotInstalled()
+            elif {defn.strategy} <= strategies <= self.resolvers[pkg.source].strategies:
+                pkg.options.strategy = defn.strategy.name
+                self.database.commit()
+                return E.PkgInstalled(pkg)
+            else:
+                return E.PkgStrategyUnsupported(Strategy.version)
 
-        return dict(zip(defns, pin(defns)))
+        return {d: pin(d, self.get_pkg(d)) for d in defns}
 
 
 def _extract_filename_from_hdr(response: aiohttp.ClientResponse) -> str:
@@ -767,19 +768,15 @@ def _init_cli_web_client(
             if params.response.headers.get(hdrs.CONTENT_ENCODING) == 'gzip':
                 total = None
 
-            counter = None
+            counter = bar(label=label, total=total)
             try:
-                counter = bar(label=label, total=total)
                 content = params.response.content
                 while not content.is_eof():
                     counter.items_completed = content.total_bytes
                     bar.invalidate()
                     await asyncio.sleep(tick_interval)
             finally:
-                try:
-                    bar.counters.remove(counter)
-                except ValueError:
-                    pass
+                bar.counters.remove(counter)
 
         tickers.add(asyncio.create_task(ticker()))
 
