@@ -16,7 +16,6 @@ from typing import (
     Optional as O,
     Sequence,
     Set,
-    Tuple,
     Union,
     cast,
 )
@@ -48,7 +47,7 @@ class _HashableModel(BaseModel):
     class Config:
         allow_mutation = False
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         return self.__dict__ == (other.__dict__ if isinstance(other, self.__class__) else other)
 
     def __hash__(self) -> int:
@@ -63,7 +62,7 @@ class Defn(_HashableModel):
     version: O[str] = None
 
     @classmethod
-    def from_pkg(cls, pkg: m.Pkg) -> Defn:
+    def from_pkg(cls, pkg: Union[m.Pkg, PkgModel]) -> Defn:
         return cls(
             source=pkg.source,
             id=pkg.id,
@@ -134,7 +133,7 @@ class Catalogue(BaseModel):
             set: sorted,
             frozenset: sorted,
         }
-        keep_untouched: Tuple[type, ...] = (cached_property,)
+        keep_untouched: Sequence[Any] = (cached_property,)
 
     @classmethod
     async def collate(cls, age_cutoff: O[datetime]) -> Catalogue:
@@ -231,7 +230,11 @@ class Resolver:
 
     async def resolve(self, defns: Sequence[Defn]) -> Dict[Defn, Any]:
         "Resolve add-on definitions into packages."
-        results = await gather(self.resolve_one(d, None) for d in defns)
+        from .manager import capture_manager_exc_async
+
+        results = await gather(
+            (self.resolve_one(d, None) for d in defns), capture_manager_exc_async
+        )
         return dict(zip(defns, results))
 
     async def resolve_one(self, defn: Defn, metadata: O[Any]) -> m.Pkg:
@@ -331,7 +334,7 @@ class CurseResolver(Resolver):
     async def resolve(self, defns: Sequence[Defn]) -> Dict[Defn, Any]:
         from aiohttp import ClientResponseError
 
-        from .manager import cache_response
+        from .manager import cache_response, capture_manager_exc_async
 
         catalogue = await self.manager.synchronise()
 
@@ -351,7 +354,8 @@ class CurseResolver(Resolver):
 
         api_results: Dict[str, CurseAddon] = {str(r['id']): r for r in json_response}
         results = await gather(
-            self.resolve_one(d, api_results.get(i)) for d, i in defns_to_ids.items()
+            (self.resolve_one(d, api_results.get(i)) for d, i in defns_to_ids.items()),
+            capture_manager_exc_async,
         )
         return dict(zip(defns, results))
 
@@ -595,7 +599,7 @@ class WowiResolver(Resolver):
     async def resolve(self, defns: Sequence[Defn]) -> Dict[Defn, Any]:
         from aiohttp import ClientResponseError
 
-        from .manager import cache_response
+        from .manager import cache_response, capture_manager_exc_async
 
         async with self.manager.locks['load WoWI catalogue']:
             if self.list_api_items is None:
@@ -623,7 +627,8 @@ class WowiResolver(Resolver):
             for i in details_api_items
         }
         results = await gather(
-            self.resolve_one(d, combined_items.get(i)) for d, i in defns_to_ids.items()
+            (self.resolve_one(d, combined_items.get(i)) for d, i in defns_to_ids.items()),
+            capture_manager_exc_async,
         )
         return dict(zip(defns, results))
 
@@ -731,7 +736,7 @@ class TukuiResolver(Resolver):
             if alias:
                 return alias
 
-    async def resolve_one(self, defn: Defn, metadata: Any) -> m.Pkg:
+    async def resolve_one(self, defn: Defn, metadata: None) -> m.Pkg:
         if defn.strategy not in self.strategies:
             raise E.PkgStrategyUnsupported(defn.strategy)
 
@@ -842,7 +847,7 @@ class GithubResolver(Resolver):
         if url.host == 'github.com' and len(url.parts) > 2:
             return '/'.join(url.parts[1:3])
 
-    async def resolve_one(self, defn: Defn, metadata: Any) -> m.Pkg:
+    async def resolve_one(self, defn: Defn, metadata: None) -> m.Pkg:
         """Resolve a hypothetical add-on hosted on GitHub.
 
         The GitHub resolver is inspired by strongbox's
@@ -933,7 +938,7 @@ class InstawowResolver(Resolver):
         ('1', 'weakauras-companion-autoupdate'),
     }
 
-    async def resolve_one(self, defn: Defn, metadata: Any) -> m.Pkg:
+    async def resolve_one(self, defn: Defn, metadata: None) -> m.Pkg:
         if defn.strategy not in self.strategies:
             raise E.PkgStrategyUnsupported(defn.strategy)
 
