@@ -25,18 +25,17 @@ from typing import (
     Iterator,
     List,
     NamedTuple,
-    Optional,
+    Optional as O,
     Sequence,
     Set,
     Tuple,
+    Type,
     TypeVar,
     Union,
     cast,
     overload,
 )
 
-from typing_extensions import Literal
-
 if TYPE_CHECKING:
     from prompt_toolkit.shortcuts import ProgressBar
 
@@ -90,14 +89,14 @@ class cached_property(Generic[_V]):
         self.f = f
 
     @overload
-    def __get__(self, o: None, t: Optional[type] = None) -> cached_property[_V]:
+    def __get__(self, o: None, t: O[type] = None) -> cached_property[_V]:
         ...
 
     @overload
-    def __get__(self, o: Any, t: Optional[type] = None) -> _V:
+    def __get__(self, o: Any, t: O[type] = None) -> _V:
         ...
 
-    def __get__(self, o: Any, t: Optional[type] = None) -> Union[cached_property[_V], _V]:
+    def __get__(self, o: Any, t: O[type] = None) -> Union[cached_property[_V], _V]:
         if o is None:
             return self
         else:
@@ -107,15 +106,15 @@ class cached_property(Generic[_V]):
 
 def bucketise(iterable: Iterable[_V], key: Callable[[_V], _H]) -> DefaultDict[_H, List[_V]]:
     "Place the elements of an iterable in a bucket according to ``key``."
-    bucket: DefaultDict[_H, List[_V]] = defaultdict(list)
+    bucket: DefaultDict[Hashable, List[object]] = defaultdict(list)
     for value in iterable:
         bucket[key(value)].append(value)
     return bucket
 
 
 def chain_dict(
-    keys: Iterable[_H], default: Any, *overrides: Iterable[Tuple[_H, Any]]
-) -> Dict[_H, Any]:
+    keys: Iterable[_H], default: Any, *overrides: Iterable[Tuple[_H, _V]]
+) -> Dict[_H, _V]:
     "Construct a dictionary from a series of iterables with overlapping keys."
     return dict(chain(zip(keys, repeat(default)), *overrides))
 
@@ -130,7 +129,7 @@ def merge_intersecting_sets(it: Iterable[_AnySet]) -> Iterable[_AnySet]:
     many_sets: Deque[AbstractSet[object]] = deque(it)
     while True:
         try:
-            this_set: AbstractSet[Any] = many_sets.popleft()
+            this_set = many_sets.popleft()
         except IndexError:
             return
 
@@ -147,27 +146,42 @@ def merge_intersecting_sets(it: Iterable[_AnySet]) -> Iterable[_AnySet]:
 
 @overload
 async def gather(
-    it: Iterable[Awaitable[_V]], return_exceptions: Literal[True] = ...
-) -> List[Union[BaseException, _V]]:
+    it: Iterable[Awaitable[_V]],
+    wrapper: Callable[..., Awaitable[_V]] = ...,
+) -> List[_V]:
     ...
 
 
 @overload
-async def gather(it: Iterable[Awaitable[_V]], return_exceptions: Literal[False] = ...) -> List[_V]:
+async def gather(it: Iterable[Awaitable[_V]], wrapper: None = ...) -> List[_V]:
     ...
 
 
 async def gather(
-    it: Iterable[Awaitable[_V]], return_exceptions: bool = True
-) -> Union[List[Union[BaseException, _V]], List[_V]]:
-    return await asyncio.gather(*it, return_exceptions=return_exceptions)
+    it: Iterable[Awaitable[_V]], wrapper: O[Callable[..., Awaitable[_V]]] = None
+) -> Sequence[_V]:
+    if wrapper is not None:
+        it = map(wrapper, it)
+    return await asyncio.gather(*it)
 
 
+@overload
+def run_in_thread(fn: Type[List[object]]) -> Callable[[Iterable[_V]], Awaitable[List[_V]]]:
+    ...
+
+
+@overload
 def run_in_thread(fn: Callable[..., _V]) -> Callable[..., Awaitable[_V]]:
+    ...
+
+
+def run_in_thread(
+    fn: Union[Type[List[object]], Callable[..., _V]]
+) -> Union[Callable[[Iterable[_V]], Awaitable[List[_V]]], Callable[..., Awaitable[_V]]]:
     @wraps(fn)
     def wrapper(*args: object, **kwargs: object):
         loop = asyncio.get_running_loop()
-        return loop.run_in_executor(None, lambda: fn(*args, **kwargs))
+        return loop.run_in_executor(None, partial(fn, *args, **kwargs))
 
     return wrapper
 
@@ -234,6 +248,7 @@ def make_progress_bar(**kwargs: Any) -> ProgressBar:
     "A ``ProgressBar`` with download progress expressed in megabytes."
     import signal
 
+    from prompt_toolkit import Application
     from prompt_toolkit.formatted_text import HTML
     from prompt_toolkit.shortcuts.progress_bar import formatters
     from prompt_toolkit.shortcuts.progress_bar.base import ProgressBar, ProgressBarCounter
@@ -248,7 +263,7 @@ def make_progress_bar(**kwargs: Any) -> ProgressBar:
     # instawow will hang.  This is my ham-fisted attempt to work
     # around all that by signalling to the daemon thread to kill the app.
 
-    _SIGWINCH = getattr(signal, "SIGWINCH", None)
+    _SIGWINCH = getattr(signal, 'SIGWINCH', None)
 
     class PatchedProgressBar(ProgressBar):
         def __exit__(self, *args: object):
@@ -258,7 +273,7 @@ def make_progress_bar(**kwargs: Any) -> ProgressBar:
 
             if self._thread is not None:
 
-                def attempt_exit(sender: Any):
+                def attempt_exit(sender: Application[object]):
                     sender.is_running and sender.exit()
 
                 self.app.on_invalidate = Event(self.app, attempt_exit)
@@ -371,7 +386,6 @@ async def is_outdated() -> Tuple[bool, str]:
                 'https://pypi.org/pypi/instawow/json'
             ) as response:
                 version = (await response.json())['info']['version']
-                print(version)
         except ClientError:
             version = __version__
         else:
