@@ -9,11 +9,17 @@ def mock(mock_all):
 
 
 @pytest.mark.asyncio
-async def test_search(manager):
+async def test_search_unfiltered(manager):
     results = await manager.search('molinari', limit=5)
     assert {Defn('curse', 'molinari'), Defn('wowi', '13188-molinari')} == set(results)
 
 
+@pytest.mark.asyncio
+async def test_search_filtered(manager):
+    results = await manager.search('molinari', limit=5, sources={'curse'})
+    assert {Defn('curse', 'molinari')} == set(results)
+
+
 @pytest.mark.asyncio
 async def test_search_caters_to_flavour(manager):
     results = await manager.search('AtlasLootClassic', limit=5)
